# Contributing to Chapa

👍🎉 First off, thanks for taking the time to contribute! 👍🎉

## Table of Contents

- [Table of Contents](#table-of-contents)
  - [Introduction](#introduction)
  - [Reporting Bugs](#reporting-bugs)
    - [How to report bugs](#how-to-report-bugs)
  - [Style Guide](#style-guide)
    - [Git Commit Messages](#git-commit-messages)
    - [Python Style Guide](#python-style-guide)
    - [Documentation](#documentation)
    - [Contributing](#contributing)

## Introduction

First of all, we are happy you are to contribute to Chapa. We are always looking for new features and improvements. If you have any suggestions, please let us know. We will be happy to hear from you. Fork the project on [Github](https://github.com/chapimenge3/chapa) and open an issue or a pull request.

## Reporting Bugs

### How to report bugs

This section is for reporting bugs. Please make sure to include the following:

    - Describe the exact steps to reproduce the bug
    - Describe the expected behavior
    - Describe the actual behavior
    - Describe the parameter data that you are passing to the API
    - Use a clear and descriptive title
    - Add bug tag to the issue

## Style Guide

So in this section we will see the style guide for the project.

### Git Commit Messages

For Git commit conventions, please follow the [Git Commit Conventions](https://www.conventionalcommits.org) and follow the [Github Linking PR to Issue](https://docs.github.com/en/issues/tracking-your-work-with-issues/linking-a-pull-request-to-an-issue)

### Python Style Guide

For Python Style Guide, please follow the [PEP8](https://www.python.org/dev/peps/pep-0008/) and [Pylint](https://pypi.org/project/pylint/)

### Documentation

For documentation, please make sure your documentation is clear and concise. Provide a detailed description of the function and its parameters. Also, please make sure that your documentation is consistent with the code.

Give examples of how to use the function. Put the expected behavior in the description.

You can make it interactive by adding emojis💯, GIFs, videos and etc.

### Contributing

Creating PR is the best way to contribute to the project. The PR should be clear and concise. The Linting Should be passed. The PR should be well written. We have prepared a PR template for you. Please follow the template.
